#Functions for doing "astronomy".

import math

def dmstodec(decd,decm,decs):
    """Convert Dec in degrees, minutes, seconds format to decimal
    degrees format.

    Keyword arguments:
    decd,decm,decs -- list of Dec values (d,m,s)

    Return value:
    decdegs -- Dec in decimal degrees

    """
    if decd < 0:
        decm = -1*decm
        decs = -1*decs
        
    decdegs = float(decd)+(float(decm)/60)+(float(decs)/3600.0)
    
    if abs(decdegs) > 90:
        raise ValueError

    return decdegs

def hmstora(rah,ram,ras):
    """Convert RA in hours, minutes, seconds format to decimal
    degrees format.

    Keyword arguments:
    rah,ram,ras -- RA values (h,m,s)

    Return value:
    radegs -- RA in decimal degrees

    """
    hrs = (float(rah)+(float(ram)/60)+(float(ras)/3600.0)) % 24

    return 15*hrs


def cartesian(ra, dec):
    """
    RA & dec (in decimal degrees) to Cartesian coordiantes on the unit sphere.
    Useful for position lookups.
    """
    x = (math.cos(math.radians(dec)) * math.cos(math.radians(ra)))
    y = (math.cos(math.radians(dec)) * math.sin(math.radians(ra)))
    z = math.sin(math.radians(dec))

    return x, y, z

